yetibot-kroki.commands.kroki


diagram-typesclj

source

encode-for-krokiclj

(encode-for-kroki graph-string)

kroki wants the graph encoded a specific way when part of a URL. See docs at https://docs.kroki.io/kroki/setup/encode-diagram/

kroki wants the graph encoded a specific way when part of a URL.
See docs at https://docs.kroki.io/kroki/setup/encode-diagram/
sourceraw docstring

graphviz-urlclj

(graphviz-url graphviz)
source

kroki-cmdclj

(kroki-cmd {[_ type-str graph-string] :match :as cmd})

kroki <type> <diagram-source> # generate a Kroki diagram of any supported type. Examples: https://kroki.io/examples.html

kroki <type> <diagram-source> # generate a Kroki diagram of any supported type. Examples: https://kroki.io/examples.html
sourceraw docstring

kroki-urlclj

(kroki-url type graph)
source

list-types-cmdclj

(list-types-cmd _)

kroki types # list types of supported diagrams

kroki types # list types of supported diagrams
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries